import datetime
import argparse

from pytsp import TSP
from pytsp.distancegetter import DistanceGetter


def gen_parser():
    """creates a command line parser and return it
    """
    parser = argparse.ArgumentParser(
        prog='pytsptest',
        description=(u"pytsptest is a command line tool that "
                     u"takes an osrm server host as argument and trie to find "
                     u"a solution to the TSP for a given set of points..."
                     ),
    )

    parser.add_argument(
        '-o',
        '--osrm',
        help=u'OSRM hostname or ip address',
        default='map.project-osrm.org',
    )

    parser.add_argument(
        '-p',
        '--points',
        help=u'Number of points to test in the matrix',
        default='4',
    )

    parser.add_argument(
        '-s',
        '--secure',
        action='store_true',
        dest='secure',
        default=False,
        help=(
            u'If this flag is set the scheme will be https. '
            u'Defaut is False (ie: http)'
        ),
    )
    return parser


if __name__ == '__main__':
    parser = gen_parser()
    args = parser.parse_args()

    points = [
        [43.83032, 4.359950],
        [50.66554, 3.104470],
        [50.31392, 2.744560],
        [50.65272, 3.025470],
        [43.70895, 7.280680],
        [43.15873, 5.714940],
        [43.53739, 4.137660],
        [43.83459, 4.360860],
        [50.72979, 1.619030],
        [43.31494, 5.441040],
        [43.34236, 5.397200],
        [44.05386, 5.049240],
        [43.34650, 3.214340],
        [50.73488, 2.734460],
        [50.55309, 3.031840],
        [43.87499, 5.398175],
        [42.69678, 9.443440],
        [43.21348, 2.349560],
        [43.31604, 1.957630],
        [42.70160, 2.894240]
    ]
    i = 3
    max_ = int(args.points)
    if args.secure:
        scheme = 'https'
    else:
        scheme = 'http'

    distance_getter = DistanceGetter(args.osrm, scheme=scheme)
    get_distance = distance_getter.get_distance

    for i in range(i, max_ + 1, 1):
        print("Compute for %s points..." % i)

        t1 = TSP(points[:i], get_distance)
        t1.init()
        time1 = datetime.datetime.now()
        res1 = t1.compute()
        time2 = datetime.datetime.now()
        delta1 = time2 - time1
        print("Result 1: %s in %s\n" % (res1, delta1))
        del t1
